==> multifear_0.1.1.tar.gz: multifear/R/utils.R <==
.onLoad <- function (libname, pkgname) {
  # set global variables in order to avoid CHECK notes
  utils::globalVariables (".")
  utils::globalVariables ("..density..")
  utils::globalVariables ("all_of")
  utils::globalVariables ("alternative")
  utils::globalVariables ("base_model_tab")
  utils::globalVariables ("base_model_time_tab")
  utils::globalVariables ("base_model_time_rand_tab")
  utils::globalVariables ("BIC")
  utils::globalVariables ("BF")
  utils::globalVariables ("bayes t-test full")
  utils::globalVariables ("cs")
  utils::globalVariables ("CS")
  utils::globalVariables ("cs.1")
  utils::globalVariables ("cs.2")
  utils::globalVariables ("cs1")
  utils::globalVariables ("cs2")
  utils::globalVariables ("cs2_id")
  utils::globalVariables ("cs_fhalf")
  utils::globalVariables ("cs_lftdiff")
  utils::globalVariables ("cs_lhalf")
  utils::globalVariables ("cs_ltrial")
  utils::globalVariables ("cs1_mean")
  utils::globalVariables ("cs1_b10per")
  utils::globalVariables ("cs1_f2trial")
  utils::globalVariables ("cs1_fhalf")
  utils::globalVariables ("cs1_ftrial")
  utils::globalVariables ("cs1_l2trial")
  utils::globalVariables ("cs1_lhalf")
  utils::globalVariables ("cs1_ltrial")
  utils::globalVariables ("cs1_minfirst")
  utils::globalVariables ("cs1_t10per")
  utils::globalVariables ("cs1_l5trial")
  utils::globalVariables ("cs2_l5trial")
  utils::globalVariables ("cs2_b10per")
  utils::globalVariables ("cs2_f2trial")
  utils::globalVariables ("cs2_fhalf")
  utils::globalVariables ("cs2_ftrial")
  utils::globalVariables ("cs2_l2trial")
  utils::globalVariables ("cs2_lhalf")
  utils::globalVariables ("cs2_ltrial")
  utils::globalVariables ("cs2_minfirst")
  utils::globalVariables ("cs2_t10per")
  utils::globalVariables ("cs2_mean")
  utils::globalVariables ("conf.high")
  utils::globalVariables ("conf.low")
  utils::globalVariables ("controls")
  utils::globalVariables ("cs_model_tab")
  utils::globalVariables ("cs_model_time_rand_tab")
  utils::globalVariables (".data")
  utils::globalVariables ("desc")
  utils::globalVariables ("diff_2_trials")
  utils::globalVariables ("diff_4_trials")
  utils::globalVariables ("diff_5_trials")
  utils::globalVariables ("difftr")
  utils::globalVariables ("Effect")
  utils::globalVariables ("effect.size")
  utils::globalVariables ("effect.size.ma")
  utils::globalVariables ("effect.size.ma.lci")
  utils::globalVariables ("effect.size.ma.hci")
  utils::globalVariables ("estimate")
  utils::globalVariables ("etasq")
  utils::globalVariables ("excl")
  utils::globalVariables ("excl_data_sets_final")
  utils::globalVariables ("framework")
  utils::globalVariables ("graph_from_data_frame")
  utils::globalVariables ("group")
  utils::globalVariables ("group2")
  utils::globalVariables ("id")
  utils::globalVariables ("include_bayes")
  utils::globalVariables ("l1trial")
  utils::globalVariables ("l2trial")
  utils::globalVariables ("method")
  utils::globalVariables ("method_order")
  utils::globalVariables ("model")
  utils::globalVariables ("models")
  utils::globalVariables ("Omega2")
  utils::globalVariables ("p.value")
  utils::globalVariables ("paired")
  utils::globalVariables ("param")
  utils::globalVariables ("Parameter")
  utils::globalVariables ("res")
  utils::globalVariables ("resp")
  utils::globalVariables ("resp2")
  utils::globalVariables ("repeated measures ANOVA with time")
  utils::globalVariables ("repeated measures ANOVA without time")
  utils::globalVariables ("rowname")
  utils::globalVariables ("start")
  utils::globalVariables ("statistic")
  utils::globalVariables ("stratum")
  utils::globalVariables ("t.value")
  utils::globalVariables ("t_boot")
  utils::globalVariables ("term")
  utils::globalVariables ("t_test_ind_boot")
  utils::globalVariables ("t_test_paired_boot")
  utils::globalVariables ("time")
  utils::globalVariables ("time_cs_model_time_tab")
  utils::globalVariables ("Value")
  utils::globalVariables ("value")
  utils::globalVariables ("var_old")
  utils::globalVariables ("x")
  utils::globalVariables ("X1")
  utils::globalVariables ("y")
  invisible ()
}

==> multifear_0.1.2.tar.gz: multifear/R/utils.R <==
.onLoad <- function (libname, pkgname) {
  # set global variables in order to avoid CHECK notes
  utils::globalVariables (".")
  utils::globalVariables ("..density..")
  utils::globalVariables ("all_of")
  utils::globalVariables ("alternative")
  utils::globalVariables ("base_model_tab")
  utils::globalVariables ("base_model_time_tab")
  utils::globalVariables ("base_model_time_rand_tab")
  utils::globalVariables ("BIC")
  utils::globalVariables ("bayes t-test full")
  utils::globalVariables ("cs")
  utils::globalVariables ("CS")
  utils::globalVariables ("cs.1")
  utils::globalVariables ("cs.2")
  utils::globalVariables ("cs1")
  utils::globalVariables ("cs2")
  utils::globalVariables ("cs2_id")
  utils::globalVariables ("cs_fhalf")
  utils::globalVariables ("cs_lftdiff")
  utils::globalVariables ("cs_lhalf")
  utils::globalVariables ("cs_ltrial")
  utils::globalVariables ("cs1_mean")
  utils::globalVariables ("cs1_b10per")
  utils::globalVariables ("cs1_f2trial")
  utils::globalVariables ("cs1_fhalf")
  utils::globalVariables ("cs1_ftrial")
  utils::globalVariables ("cs1_l2trial")
  utils::globalVariables ("cs1_lhalf")
  utils::globalVariables ("cs1_ltrial")
  utils::globalVariables ("cs1_minfirst")
  utils::globalVariables ("cs1_t10per")
  utils::globalVariables ("cs1_l5trial")
  utils::globalVariables ("cs2_l5trial")
  utils::globalVariables ("cs2_b10per")
  utils::globalVariables ("cs2_f2trial")
  utils::globalVariables ("cs2_fhalf")
  utils::globalVariables ("cs2_ftrial")
  utils::globalVariables ("cs2_l2trial")
  utils::globalVariables ("cs2_lhalf")
  utils::globalVariables ("cs2_ltrial")
  utils::globalVariables ("cs2_minfirst")
  utils::globalVariables ("cs2_t10per")
  utils::globalVariables ("cs2_mean")
  utils::globalVariables ("conf.high")
  utils::globalVariables ("conf.low")
  utils::globalVariables ("controls")
  utils::globalVariables ("cs_model_tab")
  utils::globalVariables ("cs_model_time_rand_tab")
  utils::globalVariables (".data")
  utils::globalVariables ("desc")
  utils::globalVariables ("diff_2_trials")
  utils::globalVariables ("diff_4_trials")
  utils::globalVariables ("diff_5_trials")
  utils::globalVariables ("difftr")
  utils::globalVariables ("Effect")
  utils::globalVariables ("effect.size")
  utils::globalVariables ("effect.size.ma")
  utils::globalVariables ("effect.size.ma.lci")
  utils::globalVariables ("effect.size.ma.hci")
  utils::globalVariables ("estimate")
  utils::globalVariables ("etasq")
  utils::globalVariables ("excl")
  utils::globalVariables ("excl_data_sets_final")
  utils::globalVariables ("framework")
  utils::globalVariables ("graph_from_data_frame")
  utils::globalVariables ("group")
  utils::globalVariables ("group2")
  utils::globalVariables ("id")
  utils::globalVariables ("include_bayes")
  utils::globalVariables ("l1trial")
  utils::globalVariables ("l2trial")
  utils::globalVariables ("log_BF")
  utils::globalVariables ("method")
  utils::globalVariables ("method_order")
  utils::globalVariables ("model")
  utils::globalVariables ("models")
  utils::globalVariables ("Omega2")
  utils::globalVariables ("p.value")
  utils::globalVariables ("paired")
  utils::globalVariables ("param")
  utils::globalVariables ("Parameter")
  utils::globalVariables ("res")
  utils::globalVariables ("resp")
  utils::globalVariables ("resp2")
  utils::globalVariables ("repeated measures ANOVA with time")
  utils::globalVariables ("repeated measures ANOVA without time")
  utils::globalVariables ("rowname")
  utils::globalVariables ("start")
  utils::globalVariables ("statistic")
  utils::globalVariables ("stratum")
  utils::globalVariables ("t.value")
  utils::globalVariables ("t_boot")
  utils::globalVariables ("term")
  utils::globalVariables ("t_test_ind_boot")
  utils::globalVariables ("t_test_paired_boot")
  utils::globalVariables ("time")
  utils::globalVariables ("time_cs_model_time_tab")
  utils::globalVariables ("Value")
  utils::globalVariables ("value")
  utils::globalVariables ("var_old")
  utils::globalVariables ("x")
  utils::globalVariables ("X1")
  utils::globalVariables ("y")
  invisible ()
}
